[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
01/01: Merge branch 'core-updates'.
From: |
Ludovic Courtès |
Subject: |
01/01: Merge branch 'core-updates'. |
Date: |
Wed, 04 Mar 2015 13:09:59 +0000 |
civodul pushed a commit to branch master
in repository guix.
commit 1289062522e3d08259740e59243c6cd0642a9916
Merge: cb4d3d8 da69977
Author: Ludovic Courtès <address@hidden>
Date: Wed Mar 4 14:07:23 2015 +0100
Merge branch 'core-updates'.
.dir-locals.el | 1 +
gnu-system.am | 4 +-
gnu/packages/aarddict.scm | 1 +
gnu/packages/algebra.scm | 1 +
gnu/packages/audio.scm | 11 +-
gnu/packages/autotools.scm | 9 +-
gnu/packages/base.scm | 62 ++---
gnu/packages/bioinformatics.scm | 56 ++--
gnu/packages/bison.scm | 6 +-
gnu/packages/cmake.scm | 5 +-
gnu/packages/commencement.scm | 36 ++-
gnu/packages/databases.scm | 10 +-
gnu/packages/emacs.scm | 4 +-
gnu/packages/fontutils.scm | 29 +--
gnu/packages/game-development.scm | 2 +
gnu/packages/games.scm | 3 +
gnu/packages/gawk.scm | 3 +-
gnu/packages/gettext.scm | 30 ++-
gnu/packages/gnome.scm | 47 ++++
gnu/packages/gnupg.scm | 87 +++++--
gnu/packages/gnutls.scm | 5 +-
gnu/packages/gtk.scm | 3 +-
gnu/packages/guile.scm | 11 +-
gnu/packages/image.scm | 23 +-
gnu/packages/jrnl.scm | 2 +
gnu/packages/kde.scm | 1 +
gnu/packages/ld-wrapper.scm | 11 +-
gnu/packages/libunistring.scm | 5 +-
gnu/packages/linux.scm | 5 +-
gnu/packages/mail.scm | 15 +-
gnu/packages/maths.scm | 1 +
gnu/packages/multiprecision.scm | 8 +-
gnu/packages/ninja.scm | 1 +
gnu/packages/nutrition.scm | 2 +
gnu/packages/openssl.scm | 11 +-
gnu/packages/package-management.scm | 6 +-
gnu/packages/patches/glibc-CVE-2012-3406.patch | 282 --------------------
gnu/packages/patches/glibc-CVE-2014-7817.patch | 171 ------------
.../patches/glibc-mips-dangling-vfork-ref.patch | 45 ---
gnu/packages/patches/grep-CVE-2015-1345.patch | 17 ++
gnu/packages/patches/libtool-skip-tests.patch | 28 +-
gnu/packages/python.scm | 23 +--
gnu/packages/rdf.scm | 7 +-
gnu/packages/ruby.scm | 3 +-
gnu/packages/swig.scm | 14 +-
gnu/packages/sxiv.scm | 1 +
gnu/packages/tcsh.scm | 6 +-
gnu/packages/tor.scm | 6 +-
gnu/packages/version-control.scm | 9 +
gnu/packages/web.scm | 17 +-
gnu/packages/xml.scm | 2 +-
guix/build-system/gnu.scm | 6 +-
guix/build/cmake-build-system.scm | 10 +-
guix/build/download.scm | 83 +++++--
guix/build/glib-or-gtk-build-system.scm | 11 +-
guix/build/gnu-build-system.scm | 36 +++-
guix/build/gnu-dist.scm | 17 +-
guix/build/perl-build-system.scm | 16 +-
guix/build/python-build-system.scm | 22 +-
guix/build/ruby-build-system.scm | 16 +-
guix/build/utils.scm | 142 +++++++---
guix/build/waf-build-system.scm | 13 +-
guix/gexp.scm | 7 +-
guix/packages.scm | 15 +-
tests/gexp.scm | 33 +++
65 files changed, 685 insertions(+), 890 deletions(-)
diff --cc guix/build/ruby-build-system.scm
index 4221295,40aa974..1310c4a
--- a/guix/build/ruby-build-system.scm
+++ b/guix/build/ruby-build-system.scm
@@@ -66,21 -59,14 +66,17 @@@ directory.
(setenv "GEM_HOME" gem-home)
(mkdir-p gem-home)
(zero? (system* "gem" "install" "--local"
- (first-matching-file "\\.gem$")))))
+ (first-matching-file "\\.gem$")
+ ;; Executables should go into /bin, not /lib/ruby/gems.
+ "--bindir" (string-append out "/bin")))))
(define %standard-phases
- (alist-cons-after
- 'unpack 'gitify gitify
- (alist-replace
- 'build build
- (alist-replace
- 'install install
- (alist-replace
- 'check check
- (alist-delete
- 'configure gnu:%standard-phases))))))
+ (modify-phases gnu:%standard-phases
+ (delete configure)
++ (add-after unpack gitify gitify)
+ (replace build build)
+ (replace install install)
+ (replace check check)))
(define* (ruby-build #:key inputs (phases %standard-phases)
#:allow-other-keys #:rest args)
diff --cc gnu/packages/version-control.scm
index 01d9720,71b3630..7434ed9
--- a/gnu/packages/version-control.scm
+++ b/gnu/packages/version-control.scm
@@@ -147,73 -147,72 +147,82 @@@ as well as the classic centralized work
(("/usr/bin/perl") (which "perl"))
(("/usr/bin/python") (which "python"))))
(alist-cons-after
- 'install 'split
- (lambda* (#:key inputs outputs #:allow-other-keys)
- ;; Split the binaries to the various outputs.
- (let* ((out (assoc-ref outputs "out"))
- (svn (assoc-ref outputs "svn"))
- (gui (assoc-ref outputs "gui"))
- (gitk (string-append out "/bin/gitk"))
- (gitk* (string-append gui "/bin/gitk"))
- (git-gui (string-append out "/libexec/git-core/git-gui"))
- (git-gui* (string-append gui "/libexec/git-core/git-gui"))
- (git-cit (string-append out
"/libexec/git-core/git-citool"))
- (git-cit* (string-append gui
"/libexec/git-core/git-citool"))
- (git-svn (string-append out "/libexec/git-core/git-svn"))
- (git-svn* (string-append svn "/libexec/git-core/git-svn"))
- (git-sm (string-append out
-
"/libexec/git-core/git-submodule")))
- (mkdir-p (string-append gui "/bin"))
- (mkdir-p (string-append gui "/libexec/git-core"))
- (mkdir-p (string-append svn "/libexec/git-core"))
+ 'install 'install-shell-completion
+ (lambda* (#:key outputs #:allow-other-keys)
+ (let* ((out (assoc-ref outputs "out"))
+ (completions (string-append out "/etc/bash_completion.d")))
+ ;; TODO: Install the tcsh and zsh completions in the right place.
+ (mkdir-p completions)
+ (copy-file "contrib/completion/git-completion.bash"
+ (string-append completions "/git.sh"))
+ #t))
+ (alist-cons-after
+ 'install 'split
+ (lambda* (#:key inputs outputs #:allow-other-keys)
+ ;; Split the binaries to the various outputs.
+ (let* ((out (assoc-ref outputs "out"))
+ (svn (assoc-ref outputs "svn"))
+ (gui (assoc-ref outputs "gui"))
+ (gitk (string-append out "/bin/gitk"))
+ (gitk* (string-append gui "/bin/gitk"))
+ (git-gui (string-append out "/libexec/git-core/git-gui"))
+ (git-gui* (string-append gui "/libexec/git-core/git-gui"))
+ (git-cit (string-append out
"/libexec/git-core/git-citool"))
+ (git-cit* (string-append gui
"/libexec/git-core/git-citool"))
+ (git-svn (string-append out "/libexec/git-core/git-svn"))
+ (git-svn* (string-append svn "/libexec/git-core/git-svn"))
+ (git-sm (string-append out
+
"/libexec/git-core/git-submodule")))
+ (mkdir-p (string-append gui "/bin"))
+ (mkdir-p (string-append gui "/libexec/git-core"))
+ (mkdir-p (string-append svn "/libexec/git-core"))
- (for-each (lambda (old new)
- (copy-file old new)
- (delete-file old)
- (chmod new #o555))
- (list gitk git-gui git-cit git-svn)
- (list gitk* git-gui* git-cit* git-svn*))
+ (for-each (lambda (old new)
+ (copy-file old new)
+ (delete-file old)
+ (chmod new #o555))
+ (list gitk git-gui git-cit git-svn)
+ (list gitk* git-gui* git-cit* git-svn*))
- ;; Tell 'git-svn' where Subversion is.
- (wrap-program git-svn*
- `("PATH" ":" prefix
- (,(string-append (assoc-ref inputs "subversion")
- "/bin")))
- `("PERL5LIB" ":" prefix
- (,(string-append (assoc-ref inputs "subversion")
- "/lib/perl5/site_perl")))
+ ;; Tell 'git-svn' where Subversion is.
+ (wrap-program git-svn*
+ `("PATH" ":" prefix
+ (,(string-append (assoc-ref inputs "subversion")
+ "/bin")))
+ `("PERL5LIB" ":" prefix
+ (,(string-append (assoc-ref inputs "subversion")
+ "/lib/perl5/site_perl")))
- ;; XXX: The .so for SVN/Core.pm lacks a RUNPATH, so
- ;; help it find 'libsvn_client-1.so'.
- `("LD_LIBRARY_PATH" ":" prefix
- (,(string-append (assoc-ref inputs "subversion")
- "/lib"))))
+ ;; XXX: The .so for SVN/Core.pm lacks a RUNPATH, so
+ ;; help it find 'libsvn_client-1.so'.
+ `("LD_LIBRARY_PATH" ":" prefix
+ (,(string-append (assoc-ref inputs "subversion")
+ "/lib"))))
- ;; Tell 'git-submodule' where Perl is.
- (wrap-program git-sm
- `("PATH" ":" prefix
- (,(string-append (assoc-ref inputs "perl")
- "/bin"))))
+ ;; Tell 'git-submodule' where Perl is.
+ (wrap-program git-sm
+ `("PATH" ":" prefix
+ (,(string-append (assoc-ref inputs "perl")
+ "/bin"))))
- ;; Tell 'git' to look for core programs in the user's profile.
- ;; This allows user to install other outputs of this package and
- ;; have them transparently taken into account. There's a
- ;; 'GIT_EXEC_PATH' environment variable, but it's supposed to
- ;; specify a single directory, not a search path.
- (wrap-program (string-append out "/bin/git")
- `("PATH" ":" prefix
- ("$HOME/.guix-profile/libexec/git-core")))))
- %standard-phases))))
+ ;; Tell 'git' to look for core programs in the user's profile.
+ ;; This allows user to install other outputs of this package and
+ ;; have them transparently taken into account. There's a
+ ;; 'GIT_EXEC_PATH' environment variable, but it's supposed to
+ ;; specify a single directory, not a search path.
+ (wrap-program (string-append out "/bin/git")
+ `("PATH" ":" prefix
+ ("$HOME/.guix-profile/libexec/git-core")))))
+ %standard-phases)))))
+
+ (native-search-paths
+ ;; For HTTPS access, Git needs a single-file certificate bundle, specified
+ ;; with $GIT_SSL_CAINFO.
+ ;; FIXME: This variable designates a single file; it is not a search path.
+ (list (search-path-specification
+ (variable "GIT_SSL_CAINFO")
+ (files '("etc/ssl/certs/ca-certificates.crt")))))
+
(synopsis "Distributed version control system")
(description
"Git is a free distributed version control system designed to handle